@@ -50,20 +50,19 @@ class Command(BaseCommand):
     """
 
     option_list = BaseCommand.option_list + (
-            make_option(
-                '--storage',
-                dest='storage',
-                default='dropbox',
-                help='Backend storage where the photos are'
-            ),
-            make_option(
-                '--source',
-                dest='source',
-                default='/Users/oscar/Desktop/Peques/',
-                help='Where the photos are in --storage=file'
-            ),
-        )
-
+        make_option(
+            '--storage',
+            dest='storage',
+            default='dropbox',
+            help='Backend storage where the photos are'
+        ),
+        make_option(
+            '--source',
+            dest='source',
+            default='/Users/oscar/Desktop/Peques/',
+            help='Where the photos are in --storage=file'
+        ),
+    )
 
     def handle(self, *app_labels, **options):
         """
@@ -95,18 +94,19 @@ class Command(BaseCommand):
         client, bucket = backend.get_contents(srcdir)
 
         for file in bucket:
-            img_duped, img_total, vid_duped, vid_total, total = mediasync(file,
-                                                                          srcdir,
-                                                                          photodestdir,
-                                                                          videodestdir,
-                                                                          thumbs,
-                                                                          backend,
-                                                                          client,
-                                                                          img_duped,
-                                                                          vid_duped,
-                                                                          img_total,
-                                                                          vid_total,
-                                                                          total)
+            img_duped, img_total, vid_duped, vid_total, total = mediasync(
+                file,
+                srcdir,
+                photodestdir,
+                videodestdir,
+                thumbs,
+                backend,
+                client,
+                img_duped,
+                vid_duped,
+                img_total,
+                vid_total,
+                total)
 
         print ""
         print "-"*80
