@@ -45,7 +45,15 @@ class Photos(TagMixin, ListView):
         if self.request.user.is_superuser:
             return mymodels.Photo.objects.all().order_by('-capture_date')
         else:
-            return mymodels.Photo.objects.all().filter(status=1, folder__isnull=True).order_by('-capture_date')
+            try:
+                return mymodels.Photo.objects.all().filter(
+                    status=1,
+                    folder__isnull=True,
+                    tags__slug=conf.HOMETAG).order_by('-capture_date')
+            except:
+                return mymodels.Photo.objects.all().filter(
+                    status=1,
+                    folder__isnull=True).order_by('-capture_date')
 
     def get_context_data(self, **kwargs):
         context = super(Photos, self).get_context_data(**kwargs)
@@ -67,7 +75,9 @@ class PhotosFolder(ListView):
 
     def get_queryset(self):
         folder = mymodels.Folder.objects.get(slug=self.kwargs['folder'])
-        return mymodels.Photo.objects.all().filter(status=1, folder=folder).order_by('-capture_date')
+        return mymodels.Photo.objects.all().filter(
+            status=1,
+            folder=folder).order_by('-capture_date')
 
     def get_context_data(self, **kwargs):
         context = super(PhotosFolder, self).get_context_data(**kwargs)
@@ -87,10 +97,14 @@ class PhotosTag(ListView):
 
     def get_queryset(self):
         if self.request.user.is_superuser:
-            return mymodels.Photo.objects.filter(tags__slug=self.kwargs.get('slug', None)).order_by('-capture_date')
+            return mymodels.Photo.objects.filter(
+                tags__slug=self.kwargs.get(
+                    'slug', None)).order_by('-capture_date')
         else:
-            return mymodels.Photo.objects.filter(status=1,
-                tags__slug=self.kwargs.get('slug', None)).order_by('-capture_date')
+            return mymodels.Photo.objects.filter(
+                status=1,
+                tags__slug=self.kwargs.get(
+                    'slug', None)).order_by('-capture_date')
 
     def get_context_data(self, **kwargs):
         context = super(PhotosTag, self).get_context_data(**kwargs)
@@ -163,7 +177,8 @@ class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
                              fromlist='*')
 
         # Set dirs (src, dest)
-        srcdir, photodestdir, videodestdir = backend.set_dirs(form.files['file'])
+        srcdir, photodestdir, videodestdir = backend.set_dirs(
+            form.files['file'])
 
         img_duped, img_total, vid_duped, vid_total, total = mediasync(
             form.files['file'],
@@ -218,7 +233,6 @@ class PhotoDownload(LoginRequiredMixin, ListView):
     def render_to_response(self, context):
         pk = urllib2.unquote(self.request.COOKIES.get("selected", None))
         pk = filter(None, pk.split(','))
-        response_data = {}
         # List
         s = StringIO()
         zf = zipfile.ZipFile(s, "w")
@@ -289,7 +303,8 @@ class Videos(ListView):
     paginate_by = 150
 
     def get_queryset(self):
-        vid = mymodels.Video.objects.all().filter(status=1, folder__isnull=True).order_by('-capture_date')
+        vid = mymodels.Video.objects.all().filter(
+            status=1, folder__isnull=True).order_by('-capture_date')
         print vid
         return vid
 
